/*  Creator: make/0

    Purpose: Provide index for autoload
*/

index((aggregate), 3, aggregate, aggregate).
index((aggregate), 4, aggregate, aggregate).
index((aggregate_all), 3, aggregate, aggregate).
index((aggregate_all), 4, aggregate, aggregate).
index((foldall), 4, aggregate, aggregate).
index((foreach), 2, aggregate, aggregate).
index((free_variables), 4, aggregate, aggregate).
index((ansi_format), 3, ansi_term, ansi_term).
index((ansi_get_color), 2, ansi_term, ansi_term).
index((ansi_hyperlink), 2, ansi_term, ansi_term).
index((ansi_hyperlink), 3, ansi_term, ansi_term).
index((include), 3, apply, apply).
index((exclude), 3, apply, apply).
index((partition), 4, apply, apply).
index((partition), 5, apply, apply).
index((maplist), 2, apply, apply).
index((maplist), 3, apply, apply).
index((maplist), 4, apply, apply).
index((maplist), 5, apply, apply).
index((convlist), 3, apply, apply).
index((foldl), 4, apply, apply).
index((foldl), 5, apply, apply).
index((foldl), 6, apply, apply).
index((foldl), 7, apply, apply).
index((scanl), 4, apply, apply).
index((scanl), 5, apply, apply).
index((scanl), 6, apply, apply).
index((scanl), 7, apply, apply).
index((expand_phrase), 2, apply_macros, apply_macros).
index((expand_phrase), 4, apply_macros, apply_macros).
index((apply_macros_sentinel), 0, apply_macros, apply_macros).
index((arithmetic_function), 1, arithmetic, arithmetic).
index((arithmetic_expression_value), 2, arithmetic, arithmetic).
index((empty_assoc), 1, assoc, assoc).
index((is_assoc), 1, assoc, assoc).
index((assoc_to_list), 2, assoc, assoc).
index((assoc_to_keys), 2, assoc, assoc).
index((assoc_to_values), 2, assoc, assoc).
index((gen_assoc), 3, assoc, assoc).
index((get_assoc), 3, assoc, assoc).
index((get_assoc), 5, assoc, assoc).
index((list_to_assoc), 2, assoc, assoc).
index((map_assoc), 2, assoc, assoc).
index((map_assoc), 3, assoc, assoc).
index((max_assoc), 3, assoc, assoc).
index((min_assoc), 3, assoc, assoc).
index((ord_list_to_assoc), 2, assoc, assoc).
index((put_assoc), 4, assoc, assoc).
index((del_assoc), 4, assoc, assoc).
index((del_min_assoc), 4, assoc, assoc).
index((del_max_assoc), 4, assoc, assoc).
index((restyle_identifier), 3, atom, atom).
index((identifier_parts), 2, atom, atom).
index((join_identifier_parts), 3, atom, atom).
index(('$arch'), 2, backward_compatibility, backcomp).
index(('$version'), 1, backward_compatibility, backcomp).
index(('$home'), 1, backward_compatibility, backcomp).
index(('$argv'), 1, backward_compatibility, backcomp).
index(('$set_prompt'), 1, backward_compatibility, backcomp).
index(('$strip_module'), 3, backward_compatibility, backcomp).
index(('$declare_module'), 3, backward_compatibility, backcomp).
index(('$module'), 2, backward_compatibility, backcomp).
index((at_initialization), 1, backward_compatibility, backcomp).
index((displayq), 1, backward_compatibility, backcomp).
index((displayq), 2, backward_compatibility, backcomp).
index((sformat), 2, backward_compatibility, backcomp).
index((sformat), 3, backward_compatibility, backcomp).
index((concat), 3, backward_compatibility, backcomp).
index((concat_atom), 2, backward_compatibility, backcomp).
index((concat_atom), 3, backward_compatibility, backcomp).
index(('$apropos_match'), 2, backward_compatibility, backcomp).
index((read_clause), 1, backward_compatibility, backcomp).
index((read_clause), 2, backward_compatibility, backcomp).
index((read_variables), 2, backward_compatibility, backcomp).
index((read_variables), 3, backward_compatibility, backcomp).
index((read_pending_input), 3, backward_compatibility, backcomp).
index((feature), 2, backward_compatibility, backcomp).
index((set_feature), 2, backward_compatibility, backcomp).
index((substring), 4, backward_compatibility, backcomp).
index((string_to_list), 2, backward_compatibility, backcomp).
index((string_to_atom), 2, backward_compatibility, backcomp).
index((flush), 0, backward_compatibility, backcomp).
index((write_ln), 1, backward_compatibility, backcomp).
index((proper_list), 1, backward_compatibility, backcomp).
index((free_variables), 2, backward_compatibility, backcomp).
index((hash_term), 2, backward_compatibility, backcomp).
index((checklist), 2, backward_compatibility, backcomp).
index((sublist), 3, backward_compatibility, backcomp).
index((sumlist), 2, backward_compatibility, backcomp).
index((convert_time), 2, backward_compatibility, backcomp).
index((convert_time), 8, backward_compatibility, backcomp).
index(('C'), 3, backward_compatibility, backcomp).
index((current_thread), 2, backward_compatibility, backcomp).
index((current_mutex), 3, backward_compatibility, backcomp).
index((message_queue_size), 2, backward_compatibility, backcomp).
index((lock_predicate), 2, backward_compatibility, backcomp).
index((unlock_predicate), 2, backward_compatibility, backcomp).
index((current_module), 2, backward_compatibility, backcomp).
index((export_list), 2, backward_compatibility, backcomp).
index((call_cleanup), 3, backward_compatibility, backcomp).
index((setup_and_call_cleanup), 3, backward_compatibility, backcomp).
index((setup_and_call_cleanup), 4, backward_compatibility, backcomp).
index((merge), 3, backward_compatibility, backcomp).
index((merge_set), 3, backward_compatibility, backcomp).
index((index), 1, backward_compatibility, backcomp).
index((hash), 1, backward_compatibility, backcomp).
index((set_base_module), 1, backward_compatibility, backcomp).
index((eval_license), 0, backward_compatibility, backcomp).
index((trie_insert_new), 3, backward_compatibility, backcomp).
index((thread_at_exit), 1, backward_compatibility, backcomp).
index((read_history), 6, backward_compatibility, backcomp).
index(('$sig_atomic'), 1, backward_compatibility, backcomp).
index((base32), 2, base32, base32).
index((base32), 3, base32, base32).
index((base64_encoded), 3, base64, base64).
index((base64_encoded), 4, base64, base64).
index((base64), 2, base64, base64).
index((base64), 3, base64, base64).
index((base64url), 2, base64, base64).
index((base64url), 3, base64, base64).
index((listen), 3, broadcast, broadcast).
index((listen), 2, broadcast, broadcast).
index((unlisten), 1, broadcast, broadcast).
index((unlisten), 2, broadcast, broadcast).
index((unlisten), 3, broadcast, broadcast).
index((listening), 3, broadcast, broadcast).
index((broadcast), 1, broadcast, broadcast).
index((broadcast_request), 1, broadcast, broadcast).
index((format_to_chars), 3, charsio, charsio).
index((format_to_chars), 4, charsio, charsio).
index((write_to_chars), 2, charsio, charsio).
index((write_to_chars), 3, charsio, charsio).
index((atom_to_chars), 2, charsio, charsio).
index((atom_to_chars), 3, charsio, charsio).
index((number_to_chars), 2, charsio, charsio).
index((number_to_chars), 3, charsio, charsio).
index((read_from_chars), 2, charsio, charsio).
index((read_term_from_chars), 3, charsio, charsio).
index((open_chars_stream), 2, charsio, charsio).
index((with_output_to_chars), 2, charsio, charsio).
index((with_output_to_chars), 3, charsio, charsio).
index((with_output_to_chars), 4, charsio, charsio).
index((check), 0, check, check).
index((list_undefined), 0, check, check).
index((list_undefined), 1, check, check).
index((list_autoload), 0, check, check).
index((list_redefined), 0, check, check).
index((list_cross_module_calls), 0, check, check).
index((list_cross_module_calls), 1, check, check).
index((list_void_declarations), 0, check, check).
index((list_trivial_fails), 0, check, check).
index((list_trivial_fails), 1, check, check).
index((list_format_errors), 0, check, check).
index((list_format_errors), 1, check, check).
index((list_strings), 0, check, check).
index((list_strings), 1, check, check).
index((list_rationals), 0, check, check).
index((list_rationals), 1, check, check).
index((check_installation), 0, check_installation, check_installation).
index((check_installation), 1, check_installation, check_installation).
index((check_config_files), 0, check_installation, check_installation).
index((update_config_files), 0, check_installation, check_installation).
index((test_installation), 0, check_installation, check_installation).
index((test_installation), 1, check_installation, check_installation).
index((format_to_codes), 3, codesio, codesio).
index((format_to_codes), 4, codesio, codesio).
index((write_to_codes), 2, codesio, codesio).
index((write_to_codes), 3, codesio, codesio).
index((write_term_to_codes), 3, codesio, codesio).
index((write_term_to_codes), 4, codesio, codesio).
index((read_from_codes), 2, codesio, codesio).
index((read_term_from_codes), 3, codesio, codesio).
index((open_codes_stream), 2, codesio, codesio).
index((with_output_to_codes), 2, codesio, codesio).
index((with_output_to_codes), 3, codesio, codesio).
index((with_output_to_codes), 4, codesio, codesio).
index((coinductive), 1, coinduction, coinduction).
index((csv), 3, csv, csv).
index((csv), 4, csv, csv).
index((csv_read_file), 2, csv, csv).
index((csv_read_file), 3, csv, csv).
index((csv_read_stream), 3, csv, csv).
index((csv_read_file_row), 3, csv, csv).
index((csv_read_row), 3, csv, csv).
index((csv_options), 2, csv, csv).
index((csv_write_file), 2, csv, csv).
index((csv_write_file), 3, csv, csv).
index((csv_write_stream), 3, csv, csv).
index((is_alnum), 1, ctypes, ctypes).
index((is_alpha), 1, ctypes, ctypes).
index((is_ascii), 1, ctypes, ctypes).
index((is_cntrl), 1, ctypes, ctypes).
index((is_csym), 1, ctypes, ctypes).
index((is_csymf), 1, ctypes, ctypes).
index((is_digit), 1, ctypes, ctypes).
index((is_digit), 3, ctypes, ctypes).
index((is_endfile), 1, ctypes, ctypes).
index((is_endline), 1, ctypes, ctypes).
index((is_graph), 1, ctypes, ctypes).
index((is_lower), 1, ctypes, ctypes).
index((is_newline), 1, ctypes, ctypes).
index((is_newpage), 1, ctypes, ctypes).
index((is_paren), 2, ctypes, ctypes).
index((is_period), 1, ctypes, ctypes).
index((is_print), 1, ctypes, ctypes).
index((is_punct), 1, ctypes, ctypes).
index((is_quote), 1, ctypes, ctypes).
index((is_space), 1, ctypes, ctypes).
index((is_upper), 1, ctypes, ctypes).
index((is_white), 1, ctypes, ctypes).
index((to_lower), 2, ctypes, ctypes).
index((to_upper), 2, ctypes, ctypes).
index((upper_lower), 2, ctypes, ctypes).
index((date_time_value), 3, date, date).
index((parse_time), 2, date, date).
index((parse_time), 3, date, date).
index((day_of_the_week), 2, date, date).
index((day_of_the_year), 2, date, date).
index((debug), 3, prolog_debug, debug).
index((debug), 1, prolog_debug, debug).
index((nodebug), 1, prolog_debug, debug).
index((debugging), 1, prolog_debug, debug).
index((debugging), 2, prolog_debug, debug).
index((list_debug_topics), 0, prolog_debug, debug).
index((list_debug_topics), 1, prolog_debug, debug).
index((debug_message_context), 1, prolog_debug, debug).
index((assertion), 1, prolog_debug, debug).
index((expects_dialect), 1, prolog_dialect, dialect).
index((exists_source), 1, prolog_dialect, dialect).
index((source_exports), 2, prolog_dialect, dialect).
index((mapdict), 2, dicts, dicts).
index((mapdict), 3, dicts, dicts).
index((mapdict), 4, dicts, dicts).
index((dicts_same_tag), 2, dicts, dicts).
index((dict_size), 2, dicts, dicts).
index((dict_keys), 2, dicts, dicts).
index((dicts_same_keys), 2, dicts, dicts).
index((dicts_to_same_keys), 3, dicts, dicts).
index((dict_fill), 4, dicts, dicts).
index((dict_no_fill), 3, dicts, dicts).
index((dicts_join), 3, dicts, dicts).
index((dicts_join), 4, dicts, dicts).
index((dicts_slice), 3, dicts, dicts).
index((dicts_to_compounds), 4, dicts, dicts).
index((dif), 2, dif, dif).
index((display), 1, edinburgh, edinburgh).
index((display), 2, edinburgh, edinburgh).
index((unknown), 2, edinburgh, edinburgh).
index((reconsult), 1, edinburgh, edinburgh).
index((debug), 0, edinburgh, edinburgh).
index((nodebug), 0, edinburgh, edinburgh).
index((fileerrors), 2, edinburgh, edinburgh).
index((edit), 1, prolog_edit, edit).
index((edit), 0, prolog_edit, edit).
index((instantiation_error), 1, error, error).
index((uninstantiation_error), 1, error, error).
index((type_error), 2, error, error).
index((domain_error), 2, error, error).
index((existence_error), 2, error, error).
index((existence_error), 3, error, error).
index((permission_error), 3, error, error).
index((representation_error), 1, error, error).
index((resource_error), 1, error, error).
index((syntax_error), 1, error, error).
index((must_be), 2, error, error).
index((is_of_type), 2, error, error).
index((current_type), 3, error, error).
index((catch), 4, exceptions, exceptions).
index((exception), 2, exceptions, exceptions).
index((exception_type), 2, exceptions, exceptions).
index((explain), 1, prolog_explain, explain).
index((explain), 2, prolog_explain, explain).
index((fast_read), 1, fastrw, fastrw).
index((fast_write), 1, fastrw, fastrw).
index((fast_read), 2, fastrw, fastrw).
index((fast_write), 2, fastrw, fastrw).
index((fast_write_to_string), 3, fastrw, fastrw).
index((can_open_file), 2, files, files).
index((chdir), 1, files, files).
index((reset_gensym), 0, gensym, gensym).
index((reset_gensym), 1, gensym, gensym).
index((gensym), 2, gensym, gensym).
index((git), 2, git, git).
index((git_process_output), 3, git, git).
index((git_open_file), 4, git, git).
index((is_git_directory), 1, git, git).
index((git_describe), 2, git, git).
index((git_hash), 2, git, git).
index((git_ls_tree), 2, git, git).
index((git_remote_url), 3, git, git).
index((git_ls_remote), 3, git, git).
index((git_branches), 2, git, git).
index((git_remote_branches), 2, git, git).
index((git_default_branch), 2, git, git).
index((git_current_branch), 2, git, git).
index((git_tags), 2, git, git).
index((git_tags_on_branch), 3, git, git).
index((git_shortlog), 3, git, git).
index((git_log_data), 3, git, git).
index((git_show), 4, git, git).
index((git_commit_data), 3, git, git).
index((is_git_hash), 1, git, git).
index((ht_new), 1, hashtable, hashtable).
index((ht_is_hashtable), 1, hashtable, hashtable).
index((ht_size), 2, hashtable, hashtable).
index((ht_put), 3, hashtable, hashtable).
index((ht_update), 4, hashtable, hashtable).
index((ht_put_new), 3, hashtable, hashtable).
index((ht_put), 5, hashtable, hashtable).
index((ht_del), 3, hashtable, hashtable).
index((ht_get), 3, hashtable, hashtable).
index((ht_gen), 3, hashtable, hashtable).
index((ht_pairs), 2, hashtable, hashtable).
index((ht_keys), 2, hashtable, hashtable).
index((add_to_heap), 4, heaps, heaps).
index((delete_from_heap), 4, heaps, heaps).
index((empty_heap), 1, heaps, heaps).
index((get_from_heap), 4, heaps, heaps).
index((heap_size), 2, heaps, heaps).
index((heap_to_list), 2, heaps, heaps).
index((is_heap), 1, heaps, heaps).
index((list_to_heap), 2, heaps, heaps).
index((merge_heaps), 3, heaps, heaps).
index((min_of_heap), 3, heaps, heaps).
index((min_of_heap), 5, heaps, heaps).
index((singleton_heap), 3, heaps, heaps).
index((load_hotfixes), 1, prolog_hotfix, hotfix).
index((incr_assert), 1, increval, increval).
index((incr_asserta), 1, increval, increval).
index((incr_assertz), 1, increval, increval).
index((incr_retractall), 1, increval, increval).
index((incr_retract), 1, increval, increval).
index((is_incremental_subgoal), 1, increval, increval).
index((incr_directly_depends), 2, increval, increval).
index((incr_trans_depends), 2, increval, increval).
index((incr_invalid_subgoals), 1, increval, increval).
index((incr_is_invalid), 1, increval, increval).
index((incr_invalidate_call), 1, increval, increval).
index((incr_invalidate_calls), 1, increval, increval).
index((incr_table_update), 0, increval, increval).
index((incr_propagate_calls), 1, increval, increval).
index((intercept), 3, intercept, intercept).
index((intercept), 4, intercept, intercept).
index((intercept_all), 4, intercept, intercept).
index((nb_intercept_all), 4, intercept, intercept).
index((send_signal), 1, intercept, intercept).
index((send_silent_signal), 1, intercept, intercept).
index((open_any), 5, iostream, iostream).
index((close_any), 1, iostream, iostream).
index((lazy_list), 2, lazy_lists, lazy_lists).
index((lazy_list), 3, lazy_lists, lazy_lists).
index((lazy_list_materialize), 1, lazy_lists, lazy_lists).
index((lazy_list_length), 2, lazy_lists, lazy_lists).
index((lazy_findall), 3, lazy_lists, lazy_lists).
index((lazy_findall), 4, lazy_lists, lazy_lists).
index((lazy_get_codes), 4, lazy_lists, lazy_lists).
index((lazy_read_terms), 4, lazy_lists, lazy_lists).
index((lazy_read_lines), 4, lazy_lists, lazy_lists).
index((lazy_message_queue), 4, lazy_lists, lazy_lists).
index((lazy_engine_next), 4, lazy_lists, lazy_lists).
index((lazy_list_iterator), 4, lazy_lists, lazy_lists).
index((listing), 0, prolog_listing, listing).
index((listing), 1, prolog_listing, listing).
index((listing), 2, prolog_listing, listing).
index((portray_clause), 1, prolog_listing, listing).
index((portray_clause), 2, prolog_listing, listing).
index((portray_clause), 3, prolog_listing, listing).
index((member), 2, lists, lists).
index((memberchk), 2, lists, lists).
index((append), 2, lists, lists).
index((append), 3, lists, lists).
index((prefix), 2, lists, lists).
index((select), 3, lists, lists).
index((selectchk), 3, lists, lists).
index((select), 4, lists, lists).
index((selectchk), 4, lists, lists).
index((nextto), 3, lists, lists).
index((delete), 3, lists, lists).
index((nth0), 3, lists, lists).
index((nth1), 3, lists, lists).
index((nth0), 4, lists, lists).
index((nth1), 4, lists, lists).
index((last), 2, lists, lists).
index((proper_length), 2, lists, lists).
index((same_length), 2, lists, lists).
index((reverse), 2, lists, lists).
index((permutation), 2, lists, lists).
index((flatten), 2, lists, lists).
index((clumped), 2, lists, lists).
index((subseq), 3, lists, lists).
index((max_member), 2, lists, lists).
index((min_member), 2, lists, lists).
index((max_member), 3, lists, lists).
index((min_member), 3, lists, lists).
index((sum_list), 2, lists, lists).
index((max_list), 2, lists, lists).
index((min_list), 2, lists, lists).
index((numlist), 3, lists, lists).
index((is_set), 1, lists, lists).
index((list_to_set), 2, lists, lists).
index((intersection), 3, lists, lists).
index((union), 3, lists, lists).
index((subset), 2, lists, lists).
index((subtract), 3, lists, lists).
index((macro_position), 1, macros, macros).
index((expand_macros), 5, macros, macros).
index((include_macros), 3, macros, macros).
index((main), 0, prolog_main, main).
index((argv_options), 3, prolog_main, main).
index((argv_options), 4, prolog_main, main).
index((argv_usage), 1, prolog_main, main).
index((cli_parse_debug_options), 2, prolog_main, main).
index((cli_debug_opt_type), 3, prolog_main, main).
index((cli_debug_opt_help), 2, prolog_main, main).
index((cli_debug_opt_meta), 2, prolog_main, main).
index((cli_enable_development_system), 0, prolog_main, main).
index((make), 0, make, make).
index((make_reload_file), 1, make, make).
index((in_temporary_module), 3, modules, modules).
index((current_temporary_module), 1, modules, modules).
index((nb_rb_insert), 3, nb_rbtrees, nb_rbtrees).
index((nb_rb_get_node), 3, nb_rbtrees, nb_rbtrees).
index((nb_rb_node_value), 2, nb_rbtrees, nb_rbtrees).
index((nb_rb_set_node_value), 2, nb_rbtrees, nb_rbtrees).
index((empty_nb_set), 1, nb_set, nb_set).
index((add_nb_set), 2, nb_set, nb_set).
index((add_nb_set), 3, nb_set, nb_set).
index((size_nb_set), 2, nb_set, nb_set).
index((nb_set_to_list), 2, nb_set, nb_set).
index((gen_nb_set), 2, nb_set, nb_set).
index((contains_term), 2, occurs, occurs).
index((contains_var), 2, occurs, occurs).
index((free_of_term), 2, occurs, occurs).
index((free_of_var), 2, occurs, occurs).
index((occurrences_of_term), 3, occurs, occurs).
index((occurrences_of_var), 3, occurs, occurs).
index((sub_term), 2, occurs, occurs).
index((sub_var), 2, occurs, occurs).
index((sub_term_shared_variables), 3, occurs, occurs).
index((push_operators), 1, prolog_operator, operators).
index((push_operators), 2, prolog_operator, operators).
index((pop_operators), 0, prolog_operator, operators).
index((pop_operators), 1, prolog_operator, operators).
index((push_op), 3, prolog_operator, operators).
index((option), 2, swi_option, option).
index((option), 3, swi_option, option).
index((select_option), 3, swi_option, option).
index((select_option), 4, swi_option, option).
index((merge_options), 3, swi_option, option).
index((meta_options), 3, swi_option, option).
index((dict_options), 2, swi_option, option).
index((opt_parse), 5, optparse, optparse).
index((opt_parse), 4, optparse, optparse).
index((opt_arguments), 3, optparse, optparse).
index((opt_help), 2, optparse, optparse).
index((is_ordset), 1, ordsets, ordsets).
index((list_to_ord_set), 2, ordsets, ordsets).
index((ord_add_element), 3, ordsets, ordsets).
index((ord_del_element), 3, ordsets, ordsets).
index((ord_selectchk), 3, ordsets, ordsets).
index((ord_intersect), 2, ordsets, ordsets).
index((ord_intersect), 3, ordsets, ordsets).
index((ord_intersection), 3, ordsets, ordsets).
index((ord_intersection), 4, ordsets, ordsets).
index((ord_disjoint), 2, ordsets, ordsets).
index((ord_subtract), 3, ordsets, ordsets).
index((ord_union), 2, ordsets, ordsets).
index((ord_union), 3, ordsets, ordsets).
index((ord_union), 4, ordsets, ordsets).
index((ord_subset), 2, ordsets, ordsets).
index((ord_empty), 1, ordsets, ordsets).
index((ord_memberchk), 2, ordsets, ordsets).
index((ord_symdiff), 3, ordsets, ordsets).
index((ord_seteq), 2, ordsets, ordsets).
index((ord_intersection), 2, ordsets, ordsets).
index((oset_is), 1, oset, oset).
index((oset_union), 3, oset, oset).
index((oset_int), 3, oset, oset).
index((oset_diff), 3, oset, oset).
index((oset_dint), 2, oset, oset).
index((oset_dunion), 2, oset, oset).
index((oset_addel), 3, oset, oset).
index((oset_delel), 3, oset, oset).
index((oset_power), 2, oset, oset).
index((pairs_keys_values), 3, pairs, pairs).
index((pairs_values), 2, pairs, pairs).
index((pairs_keys), 2, pairs, pairs).
index((group_pairs_by_key), 2, pairs, pairs).
index((transpose_pairs), 2, pairs, pairs).
index((map_list_to_pairs), 3, pairs, pairs).
index((persistent), 1, persistency, persistency).
index((current_persistent_predicate), 1, persistency, persistency).
index((db_attach), 2, persistency, persistency).
index((db_detach), 0, persistency, persistency).
index((db_attached), 1, persistency, persistency).
index((db_sync), 1, persistency, persistency).
index((db_sync_all), 1, persistency, persistency).
index((portray_text), 1, portray_text, portray_text).
index((set_portray_text), 2, portray_text, portray_text).
index((set_portray_text), 3, portray_text, portray_text).
index((print_term), 2, prolog_pretty_print, pprint).
index((predicate_options), 3, predicate_options, predicate_options).
index((assert_predicate_options), 4, predicate_options, predicate_options).
index((current_option_arg), 2, predicate_options, predicate_options).
index((current_predicate_option), 3, predicate_options, predicate_options).
index((check_predicate_option), 3, predicate_options, predicate_options).
index((current_predicate_options), 3, predicate_options, predicate_options).
index((retractall_predicate_options), 0, predicate_options, predicate_options).
index((derived_predicate_options), 3, predicate_options, predicate_options).
index((derived_predicate_options), 1, predicate_options, predicate_options).
index((check_predicate_options), 0, predicate_options, predicate_options).
index((derive_predicate_options), 0, predicate_options, predicate_options).
index((check_predicate_options), 1, predicate_options, predicate_options).
index((autoload_all), 0, prolog_autoload, prolog_autoload).
index((autoload_all), 1, prolog_autoload, prolog_autoload).
index((set_breakpoint), 4, prolog_breakpoints, prolog_breakpoints).
index((set_breakpoint), 5, prolog_breakpoints, prolog_breakpoints).
index((set_breakpoint_condition), 2, prolog_breakpoints, prolog_breakpoints).
index((delete_breakpoint), 1, prolog_breakpoints, prolog_breakpoints).
index((breakpoint_property), 2, prolog_breakpoints, prolog_breakpoints).
index((clause_info), 4, prolog_clause, prolog_clause).
index((clause_info), 5, prolog_clause, prolog_clause).
index((initialization_layout), 4, prolog_clause, prolog_clause).
index((predicate_name), 2, prolog_clause, prolog_clause).
index((clause_name), 2, prolog_clause, prolog_clause).
index((comma_list), 2, prolog_code, prolog_code).
index((semicolon_list), 2, prolog_code, prolog_code).
index((mkconj), 3, prolog_code, prolog_code).
index((mkdisj), 3, prolog_code, prolog_code).
index((pi_head), 2, prolog_code, prolog_code).
index((head_name_arity), 3, prolog_code, prolog_code).
index((most_general_goal), 2, prolog_code, prolog_code).
index((extend_goal), 3, prolog_code, prolog_code).
index((predicate_label), 2, prolog_code, prolog_code).
index((predicate_sort_key), 2, prolog_code, prolog_code).
index((is_control_goal), 1, prolog_code, prolog_code).
index((is_predicate_indicator), 1, prolog_code, prolog_code).
index((body_term_calls), 2, prolog_code, prolog_code).
index((prolog_walk_code), 1, prolog_codewalk, prolog_codewalk).
index((prolog_program_clause), 2, prolog_codewalk, prolog_codewalk).
index((prolog_colourise_stream), 3, prolog_colour, prolog_colour).
index((prolog_colourise_stream), 4, prolog_colour, prolog_colour).
index((prolog_colourise_term), 4, prolog_colour, prolog_colour).
index((prolog_colourise_query), 3, prolog_colour, prolog_colour).
index((syntax_colour), 2, prolog_colour, prolog_colour).
index((syntax_message), 3, prolog_colour, prolog_colour).
index((prolog_dump_runtime_variables), 0, prolog_config, prolog_config).
index((prolog_config), 2, prolog_config, prolog_config).
index((coverage), 1, prolog_coverage, prolog_coverage).
index((coverage), 2, prolog_coverage, prolog_coverage).
index((show_coverage), 1, prolog_coverage, prolog_coverage).
index((show_coverage), 2, prolog_coverage, prolog_coverage).
index((cov_save_data), 2, prolog_coverage, prolog_coverage).
index((cov_load_data), 2, prolog_coverage, prolog_coverage).
index((cov_reset), 0, prolog_coverage, prolog_coverage).
index((cov_property), 1, prolog_coverage, prolog_coverage).
index((spy), 1, prolog_debug_tools, prolog_debug).
index((nospy), 1, prolog_debug_tools, prolog_debug).
index((nospyall), 0, prolog_debug_tools, prolog_debug).
index((debugging), 0, prolog_debug_tools, prolog_debug).
index((trap), 1, prolog_debug_tools, prolog_debug).
index((notrap), 1, prolog_debug_tools, prolog_debug).
index((file_autoload_directives), 3, prolog_deps, prolog_deps).
index((file_auto_import), 2, prolog_deps, prolog_deps).
index((evaluable_property), 2, prolog_evaluable, prolog_evaluable).
index((format_spec), 2, prolog_format, prolog_format).
index((format_spec), 3, prolog_format, prolog_format).
index((format_types), 2, prolog_format, prolog_format).
index((prolog_history), 1, prolog_history, prolog_history).
index((jiti_list), 0, prolog_jiti, prolog_jiti).
index((jiti_list), 1, prolog_jiti, prolog_jiti).
index((jiti_suggest_modes), 1, prolog_jiti, prolog_jiti).
index((jiti_suggest_modes), 0, prolog_jiti, prolog_jiti).
index((setup_prolog_integer_grouping), 0, prolog_locale, prolog_locale).
index((infer_meta_predicate), 2, prolog_metainference, prolog_metainference).
index((inferred_meta_predicate), 2, prolog_metainference, prolog_metainference).
index((pack_list_installed), 0, prolog_pack, prolog_pack).
index((pack_info), 1, prolog_pack, prolog_pack).
index((pack_list), 1, prolog_pack, prolog_pack).
index((pack_list), 2, prolog_pack, prolog_pack).
index((pack_search), 1, prolog_pack, prolog_pack).
index((pack_install), 1, prolog_pack, prolog_pack).
index((pack_install), 2, prolog_pack, prolog_pack).
index((pack_install_local), 3, prolog_pack, prolog_pack).
index((pack_upgrade), 1, prolog_pack, prolog_pack).
index((pack_rebuild), 1, prolog_pack, prolog_pack).
index((pack_rebuild), 0, prolog_pack, prolog_pack).
index((pack_remove), 1, prolog_pack, prolog_pack).
index((pack_remove), 2, prolog_pack, prolog_pack).
index((pack_publish), 2, prolog_pack, prolog_pack).
index((pack_property), 2, prolog_pack, prolog_pack).
index((profile), 1, prolog_profile, prolog_profile).
index((profile), 2, prolog_profile, prolog_profile).
index((show_profile), 1, prolog_profile, prolog_profile).
index((profile_data), 1, prolog_profile, prolog_profile).
index((profile_procedure_data), 2, prolog_profile, prolog_profile).
index((qlf_make), 0, prolog_qlfmake, prolog_qlfmake).
index((qlf_make), 1, prolog_qlfmake, prolog_qlfmake).
index((prolog_read_source_term), 4, prolog_source, prolog_source).
index((read_source_term_at_location), 3, prolog_source, prolog_source).
index((prolog_open_source), 2, prolog_source, prolog_source).
index((prolog_close_source), 1, prolog_source, prolog_source).
index((prolog_canonical_source), 2, prolog_source, prolog_source).
index((load_quasi_quotation_syntax), 2, prolog_source, prolog_source).
index((file_name_on_path), 2, prolog_source, prolog_source).
index((file_alias_path), 2, prolog_source, prolog_source).
index((path_segments_atom), 2, prolog_source, prolog_source).
index((directory_source_files), 3, prolog_source, prolog_source).
index((valid_term_position), 2, prolog_source, prolog_source).
index((get_prolog_backtrace), 2, prolog_stack, prolog_stack).
index((get_prolog_backtrace), 3, prolog_stack, prolog_stack).
index((prolog_stack_frame_property), 2, prolog_stack, prolog_stack).
index((print_prolog_backtrace), 2, prolog_stack, prolog_stack).
index((print_prolog_backtrace), 3, prolog_stack, prolog_stack).
index((backtrace), 1, prolog_stack, prolog_stack).
index((print_last_choicepoint), 0, prolog_stack, prolog_stack).
index((print_last_choicepoint), 2, prolog_stack, prolog_stack).
index((trace), 1, prolog_trace, prolog_trace).
index((trace), 2, prolog_trace, prolog_trace).
index((tracing), 2, prolog_trace, prolog_trace).
index((list_tracing), 0, prolog_trace, prolog_trace).
index((notraceall), 0, prolog_trace, prolog_trace).
index((require_prolog_version), 2, prolog_versions, prolog_versions).
index((require_version), 3, prolog_versions, prolog_versions).
index((cmp_versions), 3, prolog_versions, prolog_versions).
index((wrap_predicate), 4, prolog_wrap, prolog_wrap).
index((unwrap_predicate), 2, prolog_wrap, prolog_wrap).
index((current_predicate_wrapper), 4, prolog_wrap, prolog_wrap).
index((xref_source), 1, prolog_xref, prolog_xref).
index((xref_source), 2, prolog_xref, prolog_xref).
index((xref_called), 3, prolog_xref, prolog_xref).
index((xref_called), 4, prolog_xref, prolog_xref).
index((xref_called), 5, prolog_xref, prolog_xref).
index((xref_defined), 3, prolog_xref, prolog_xref).
index((xref_definition_line), 2, prolog_xref, prolog_xref).
index((xref_exported), 2, prolog_xref, prolog_xref).
index((xref_module), 2, prolog_xref, prolog_xref).
index((xref_uses_file), 3, prolog_xref, prolog_xref).
index((xref_op), 2, prolog_xref, prolog_xref).
index((xref_prolog_flag), 4, prolog_xref, prolog_xref).
index((xref_comment), 3, prolog_xref, prolog_xref).
index((xref_comment), 4, prolog_xref, prolog_xref).
index((xref_mode), 3, prolog_xref, prolog_xref).
index((xref_option), 2, prolog_xref, prolog_xref).
index((xref_clean), 1, prolog_xref, prolog_xref).
index((xref_current_source), 1, prolog_xref, prolog_xref).
index((xref_done), 2, prolog_xref, prolog_xref).
index((xref_built_in), 1, prolog_xref, prolog_xref).
index((xref_source_file), 3, prolog_xref, prolog_xref).
index((xref_source_file), 4, prolog_xref, prolog_xref).
index((xref_public_list), 3, prolog_xref, prolog_xref).
index((xref_public_list), 4, prolog_xref, prolog_xref).
index((xref_public_list), 6, prolog_xref, prolog_xref).
index((xref_public_list), 7, prolog_xref, prolog_xref).
index((xref_meta), 3, prolog_xref, prolog_xref).
index((xref_meta), 2, prolog_xref, prolog_xref).
index((xref_hook), 1, prolog_xref, prolog_xref).
index((xref_used_class), 2, prolog_xref, prolog_xref).
index((xref_defined_class), 3, prolog_xref, prolog_xref).
index((phrase_from_file), 2, pure_input, pure_input).
index((phrase_from_file), 3, pure_input, pure_input).
index((phrase_from_stream), 2, pure_input, pure_input).
index((stream_to_lazy_list), 2, pure_input, pure_input).
index((syntax_error), 3, pure_input, pure_input).
index((lazy_list_location), 3, pure_input, pure_input).
index((lazy_list_character_count), 3, pure_input, pure_input).
index((load_foreign_files), 0, qp_foreign, qpforeign).
index((load_foreign_files), 2, qp_foreign, qpforeign).
index((load_foreign_files), 3, qp_foreign, qpforeign).
index((make_shared_object), 3, qp_foreign, qpforeign).
index((make_foreign_wrapper_file), 1, qp_foreign, qpforeign).
index((make_foreign_wrapper_file), 2, qp_foreign, qpforeign).
index((make_foreign_resource_wrapper), 3, qp_foreign, qpforeign).
index((load_foreign_resource), 2, qp_foreign, qpforeign).
index((qsave_program), 1, qsave, qsave).
index((qsave_program), 2, qsave, qsave).
index((with_quasi_quotation_input), 3, quasi_quotations, quasi_quotations).
index((phrase_from_quasi_quotation), 2, quasi_quotations, quasi_quotations).
index((quasi_quotation_syntax_error), 1, quasi_quotations, quasi_quotations).
index((quasi_quotation_syntax), 1, quasi_quotations, quasi_quotations).
index((unix), 1, quintus, quintus).
index((abs), 2, quintus, quintus).
index((sin), 2, quintus, quintus).
index((cos), 2, quintus, quintus).
index((tan), 2, quintus, quintus).
index((log), 2, quintus, quintus).
index((log10), 2, quintus, quintus).
index((pow), 3, quintus, quintus).
index((ceiling), 2, quintus, quintus).
index((floor), 2, quintus, quintus).
index((round), 2, quintus, quintus).
index((acos), 2, quintus, quintus).
index((asin), 2, quintus, quintus).
index((atan), 2, quintus, quintus).
index((atan2), 3, quintus, quintus).
index((sign), 2, quintus, quintus).
index((sqrt), 2, quintus, quintus).
index((genarg), 3, quintus, quintus).
index((no_style_check), 1, quintus, quintus).
index((otherwise), 0, quintus, quintus).
index((simple), 1, quintus, quintus).
index((prolog_flag), 2, quintus, quintus).
index((date), 1, quintus, quintus).
index((current_stream), 3, quintus, quintus).
index((stream_position), 3, quintus, quintus).
index((skip_line), 0, quintus, quintus).
index((skip_line), 1, quintus, quintus).
index((compile), 1, quintus, quintus).
index((atom_char), 2, quintus, quintus).
index((midstring), 3, quintus, quintus).
index((midstring), 4, quintus, quintus).
index((midstring), 5, quintus, quintus).
index((midstring), 6, quintus, quintus).
index((raise_exception), 1, quintus, quintus).
index((on_exception), 3, quintus, quintus).
index((random), 1, random, random).
index((random_between), 3, random, random).
index((getrand), 1, random, random).
index((setrand), 1, random, random).
index((maybe), 0, random, random).
index((maybe), 1, random, random).
index((maybe), 2, random, random).
index((random_perm2), 4, random, random).
index((random_member), 2, random, random).
index((random_select), 3, random, random).
index((random_subseq), 3, random, random).
index((randseq), 3, random, random).
index((randset), 3, random, random).
index((random_permutation), 2, random, random).
index((random_numlist), 4, random, random).
index((random), 3, random, random).
index((rb_new), 1, rbtrees, rbtrees).
index((rb_empty), 1, rbtrees, rbtrees).
index((rb_lookup), 3, rbtrees, rbtrees).
index((rb_update), 4, rbtrees, rbtrees).
index((rb_update), 5, rbtrees, rbtrees).
index((rb_apply), 4, rbtrees, rbtrees).
index((rb_insert), 4, rbtrees, rbtrees).
index((rb_insert_new), 4, rbtrees, rbtrees).
index((rb_delete), 3, rbtrees, rbtrees).
index((rb_delete), 4, rbtrees, rbtrees).
index((rb_visit), 2, rbtrees, rbtrees).
index((rb_keys), 2, rbtrees, rbtrees).
index((rb_map), 2, rbtrees, rbtrees).
index((rb_map), 3, rbtrees, rbtrees).
index((rb_partial_map), 4, rbtrees, rbtrees).
index((rb_fold), 4, rbtrees, rbtrees).
index((rb_clone), 3, rbtrees, rbtrees).
index((rb_min), 3, rbtrees, rbtrees).
index((rb_max), 3, rbtrees, rbtrees).
index((rb_del_min), 4, rbtrees, rbtrees).
index((rb_del_max), 4, rbtrees, rbtrees).
index((rb_next), 4, rbtrees, rbtrees).
index((rb_previous), 4, rbtrees, rbtrees).
index((list_to_rbtree), 2, rbtrees, rbtrees).
index((ord_list_to_rbtree), 2, rbtrees, rbtrees).
index((is_rbtree), 1, rbtrees, rbtrees).
index((rb_size), 2, rbtrees, rbtrees).
index((rb_in), 3, rbtrees, rbtrees).
index((readln), 1, readln, readln).
index((readln), 2, readln, readln).
index((readln), 5, readln, readln).
index((read_line_to_codes), 2, read_util, readutil).
index((read_line_to_codes), 3, read_util, readutil).
index((read_stream_to_codes), 2, read_util, readutil).
index((read_stream_to_codes), 3, read_util, readutil).
index((read_file_to_codes), 3, read_util, readutil).
index((read_line_to_string), 2, read_util, readutil).
index((read_file_to_string), 3, read_util, readutil).
index((read_file_to_terms), 3, read_util, readutil).
index((record), 1, record, record).
index((current_record), 2, record, record).
index((current_record_predicate), 2, record, record).
index((with_rwlock), 3, rwlocks, rwlocks).
index((with_rwlock), 4, rwlocks, rwlocks).
index((safe_goal), 1, sandbox, sandbox).
index((safe_call), 1, sandbox, sandbox).
index((setting), 4, settings, settings).
index((setting), 2, settings, settings).
index((set_setting), 2, settings, settings).
index((set_setting_default), 2, settings, settings).
index((restore_setting), 1, settings, settings).
index((load_settings), 1, settings, settings).
index((load_settings), 2, settings, settings).
index((save_settings), 0, settings, settings).
index((save_settings), 1, settings, settings).
index((current_setting), 1, settings, settings).
index((setting_property), 2, settings, settings).
index((list_settings), 0, settings, settings).
index((list_settings), 1, settings, settings).
index((convert_setting_text), 3, settings, settings).
index((shell), 0, shell, shell).
index((ls), 0, shell, shell).
index((ls), 1, shell, shell).
index((cd), 0, shell, shell).
index((cd), 1, shell, shell).
index((pushd), 0, shell, shell).
index((pushd), 1, shell, shell).
index((dirs), 0, shell, shell).
index((pwd), 0, shell, shell).
index((popd), 0, shell, shell).
index((mv), 2, shell, shell).
index((rm), 1, shell, shell).
index((load_foreign_library), 1, shlib, shlib).
index((load_foreign_library), 2, shlib, shlib).
index((unload_foreign_library), 1, shlib, shlib).
index((unload_foreign_library), 2, shlib, shlib).
index((current_foreign_library), 2, shlib, shlib).
index((reload_foreign_libraries), 0, shlib, shlib).
index((use_foreign_library), 1, shlib, shlib).
index((use_foreign_library), 2, shlib, shlib).
index((distinct), 1, solution_sequences, solution_sequences).
index((distinct), 2, solution_sequences, solution_sequences).
index((reduced), 1, solution_sequences, solution_sequences).
index((reduced), 3, solution_sequences, solution_sequences).
index((limit), 2, solution_sequences, solution_sequences).
index((offset), 2, solution_sequences, solution_sequences).
index((call_nth), 2, solution_sequences, solution_sequences).
index((order_by), 2, solution_sequences, solution_sequences).
index((group_by), 4, solution_sequences, solution_sequences).
index((predsort), 3, sort, sort).
index((locale_sort), 2, sort, sort).
index((statistics), 0, prolog_statistics, statistics).
index((statistics), 1, prolog_statistics, statistics).
index((thread_statistics), 2, prolog_statistics, statistics).
index((time), 1, prolog_statistics, statistics).
index((call_time), 2, prolog_statistics, statistics).
index((call_time), 3, prolog_statistics, statistics).
index((with_output_to), 3, streams, streams).
index((dedent_lines), 3, strings, strings).
index((indent_lines), 3, strings, strings).
index((indent_lines), 4, strings, strings).
index((interpolate_string), 4, strings, strings).
index((string_lines), 2, strings, strings).
index((string), 4, strings, strings).
index((lock_predicate), 1, swi_system_utilities, system).
index((unlock_predicate), 1, swi_system_utilities, system).
index((system_mode), 1, swi_system_utilities, system).
index((system_module), 0, swi_system_utilities, system).
index((abolish_all_tables), 0, tables, tables).
index((abolish_module_tables), 1, tables, tables).
index((abolish_table_pred), 1, tables, tables).
index((abolish_table_call), 1, tables, tables).
index((abolish_table_call), 2, tables, tables).
index((abolish_table_subgoals), 2, tables, tables).
index((tfindall), 3, tables, tables).
index(('t not'), 1, tables, tables).
index((get_call), 3, tables, tables).
index((get_calls), 3, tables, tables).
index((get_returns), 2, tables, tables).
index((get_returns), 3, tables, tables).
index((get_returns_and_dls), 3, tables, tables).
index((get_returns_and_tvs), 3, tables, tables).
index((get_returns_for_call), 2, tables, tables).
index((get_residual), 2, tables, tables).
index((set_pil_on), 0, tables, tables).
index((set_pil_off), 0, tables, tables).
index((term_hash), 2, terms, terms).
index((term_hash), 4, terms, terms).
index((term_size), 2, terms, terms).
index((term_variables), 2, terms, terms).
index((term_variables), 3, terms, terms).
index((variant), 2, terms, terms).
index((subsumes), 2, terms, terms).
index((subsumes_chk), 2, terms, terms).
index((cyclic_term), 1, terms, terms).
index((acyclic_term), 1, terms, terms).
index((term_subsumer), 3, terms, terms).
index((term_factorized), 3, terms, terms).
index((mapargs), 3, terms, terms).
index((mapsubterms), 3, terms, terms).
index((mapsubterms_var), 3, terms, terms).
index((foldsubterms), 4, terms, terms).
index((foldsubterms), 5, terms, terms).
index((same_functor), 2, terms, terms).
index((same_functor), 3, terms, terms).
index((same_functor), 4, terms, terms).
index((concurrent), 3, thread, thread).
index((concurrent_maplist), 2, thread, thread).
index((concurrent_maplist), 3, thread, thread).
index((concurrent_maplist), 4, thread, thread).
index((concurrent_forall), 2, thread, thread).
index((concurrent_forall), 3, thread, thread).
index((concurrent_and), 2, thread, thread).
index((concurrent_and), 3, thread, thread).
index((first_solution), 3, thread, thread).
index((call_in_thread), 2, thread, thread).
index((thread_pool_create), 3, thread_pool, thread_pool).
index((thread_pool_destroy), 1, thread_pool, thread_pool).
index((thread_create_in_pool), 4, thread_pool, thread_pool).
index((current_thread_pool), 1, thread_pool, thread_pool).
index((thread_pool_property), 2, thread_pool, thread_pool).
index((threads), 0, thread_util, threadutil).
index((join_threads), 0, thread_util, threadutil).
index((with_stopped_threads), 2, thread_util, threadutil).
index((thread_has_console), 0, thread_util, threadutil).
index((attach_console), 0, thread_util, threadutil).
index((attach_console), 1, thread_util, threadutil).
index((tspy), 1, thread_util, threadutil).
index((tspy), 2, thread_util, threadutil).
index((tdebug), 0, thread_util, threadutil).
index((tdebug), 1, thread_util, threadutil).
index((tnodebug), 0, thread_util, threadutil).
index((tnodebug), 1, thread_util, threadutil).
index((tprofile), 1, thread_util, threadutil).
index((tbacktrace), 1, thread_util, threadutil).
index((tbacktrace), 2, thread_util, threadutil).
index((thread_run_interactor), 0, thread_util, threadutil).
index((interactor), 0, thread_util, threadutil).
index((interactor), 1, thread_util, threadutil).
index((tty_clear), 0, tty, tty).
index((tty_flash), 0, tty, tty).
index((menu), 3, tty, tty).
index((add_edges), 3, ugraphs, ugraphs).
index((add_vertices), 3, ugraphs, ugraphs).
index((complement), 2, ugraphs, ugraphs).
index((compose), 3, ugraphs, ugraphs).
index((del_edges), 3, ugraphs, ugraphs).
index((del_vertices), 3, ugraphs, ugraphs).
index((edges), 2, ugraphs, ugraphs).
index((neighbors), 3, ugraphs, ugraphs).
index((neighbours), 3, ugraphs, ugraphs).
index((reachable), 3, ugraphs, ugraphs).
index((top_sort), 2, ugraphs, ugraphs).
index((ugraph_layers), 2, ugraphs, ugraphs).
index((transitive_closure), 2, ugraphs, ugraphs).
index((transpose_ugraph), 2, ugraphs, ugraphs).
index((vertices), 2, ugraphs, ugraphs).
index((vertices_edges_to_ugraph), 3, ugraphs, ugraphs).
index((ugraph_union), 3, ugraphs, ugraphs).
index((connect_ugraph), 3, ugraphs, ugraphs).
index((parse_url), 2, url, url).
index((parse_url), 3, url, url).
index((is_absolute_url), 1, url, url).
index((global_url), 3, url, url).
index((http_location), 2, url, url).
index((www_form_encode), 2, url, url).
index((parse_url_search), 2, url, url).
index((url_iri), 2, url, url).
index((file_name_to_url), 2, url, url).
index((set_url_encoding), 2, url, url).
index((utf8_codes), 3, utf8, utf8).
index((numbervars), 1, varnumbers, varnumbers).
index((varnumbers), 2, varnumbers, varnumbers).
index((max_var_number), 3, varnumbers, varnumbers).
index((varnumbers), 3, varnumbers, varnumbers).
index((varnumbers_names), 3, varnumbers, varnumbers).
index((vm_list), 1, prolog_vm, vm).
index((clause_vm), 2, prolog_vm, vm).
index((vmi_labels), 2, prolog_vm, vm).
index((call_residual_program), 2, wfs, wfs).
index((call_delays), 2, wfs, wfs).
index((delays_residual_program), 2, wfs, wfs).
index((answer_residual), 2, wfs, wfs).
index((when), 2, when, when).
index((writef), 1, writef, writef).
index((writef), 2, writef, writef).
index((swritef), 2, writef, writef).
index((swritef), 3, writef, writef).
index((www_open_url), 1, www_browser, www_browser).
index((expand_url_path), 2, www_browser, www_browser).
index((>>), 2, yall, yall).
index((>>), 3, yall, yall).
index((>>), 4, yall, yall).
index((>>), 5, yall, yall).
index((>>), 6, yall, yall).
index((>>), 7, yall, yall).
index((>>), 8, yall, yall).
index((>>), 9, yall, yall).
index((/), 2, yall, yall).
index((/), 3, yall, yall).
index((/), 4, yall, yall).
index((/), 5, yall, yall).
index((/), 6, yall, yall).
index((/), 7, yall, yall).
index((/), 8, yall, yall).
index((/), 9, yall, yall).
index((lambda_calls), 2, yall, yall).
index((lambda_calls), 3, yall, yall).
index((is_lambda), 1, yall, yall).
index((zip_open), 4, zip, zip).
index((zip_close), 1, zip, zip).
index((zip_close), 2, zip, zip).
index((with_zipper), 2, zip, zip).
index((zipper_open_new_file_in_zip), 4, zip, zip).
index((zipper_goto), 2, zip, zip).
index((zipper_open_current), 3, zip, zip).
index((zipper_members), 2, zip, zip).
index((zipper_file_info), 3, zip, zip).
